==> datanator_query_python-0.0.3.tar.gz: datanator_query_python-0.0.3/README.md <==
[//]: # ( [![PyPI package](https://img.shields.io/pypi/v/datanator_query_python.svg)](https://pypi.python.org/pypi/datanator_query_python) )
[![Documentation](https://readthedocs.org/projects/datanator-query-python/badge/?version=latest)](https://docs.karrlab.org/datanator_query_python)
[![Test results](https://circleci.com/gh/KarrLab/datanator_query_python.svg?style=shield)](https://circleci.com/gh/KarrLab/datanator_query_python)
[![Test coverage](https://coveralls.io/repos/github/KarrLab/datanator_query_python/badge.svg)](https://coveralls.io/github/KarrLab/datanator_query_python)
[![Code analysis](https://api.codeclimate.com/v1/badges/141d01cec991d17ed5ab/maintainability)](https://codeclimate.com/github/KarrLab/datanator_query_python)
[![License](https://img.shields.io/github/license/KarrLab/datanator_query_python.svg)](LICENSE)
![Analytics](https://ga-beacon.appspot.com/UA-86759801-1/datanator_query_python/README.md?pixel)

# datanator_query_python

Write an overview

## Installation

1. Install dependencies
2. Install the latest release from PyPI

```
pip install datanator_query_python.git[all]
```

3. Install the latest revision from GitHub

```
pip install git+https://github.com/KarrLab/datanator_query_python.git#egg=datanator_query_python[all]
```

## Documentation

Please see the [API documentation](https://docs.karrlab.org/datanator_query_python).

## License

The package is released under the [MIT license](LICENSE).

## Development team

This package was developed by the [Karr Lab](https://www.karrlab.org) at the Icahn School of Medicine at Mount Sinai in New York, USA.

## Questions and comments

Please contact the [Karr Lab](mailto:info@karrlab.org) with any questions or comments.

==> datanator_query_python-0.4.6.tar.gz: datanator_query_python-0.4.6/README.md <==
[//]: # ( [![PyPI package](https://img.shields.io/pypi/v/datanator_query_python.svg)](https://pypi.python.org/pypi/datanator_query_python) )
[![Documentation](https://readthedocs.org/projects/datanator-query-python/badge/?version=latest)](https://docs.karrlab.org/datanator_query_python)
[![Test results](https://circleci.com/gh/KarrLab/datanator_query_python.svg?style=shield)](https://circleci.com/gh/KarrLab/datanator_query_python)
[![Test coverage](https://coveralls.io/repos/github/KarrLab/datanator_query_python/badge.svg)](https://coveralls.io/github/KarrLab/datanator_query_python)
[![Code analysis](https://api.codeclimate.com/v1/badges/141d01cec991d17ed5ab/maintainability)](https://codeclimate.com/github/KarrLab/datanator_query_python)
[![License](https://img.shields.io/github/license/KarrLab/datanator_query_python.svg)](LICENSE)
![Analytics](https://ga-beacon.appspot.com/UA-86759801-1/datanator_query_python/README.md?pixel)

# datanator_query_python

Write an overview

## Installation

1. Install dependencies
2. Install the latest release from PyPI

```
pip install datanator-query-python
```

3. Install the latest revision from GitHub

```
pip install git+https://github.com/KarrLab/datanator_query_python.git#egg=datanator_query_python[all]
```

## Documentation

Please see the [API documentation](https://docs.karrlab.org/datanator_query_python).

## License

The package is released under the [MIT license](LICENSE).

## Development team

This package was developed by the [Karr Lab](https://www.karrlab.org) at the Icahn School of Medicine at Mount Sinai in New York, USA.

## Questions and comments

Please contact the [Karr Lab](mailto:info@karrlab.org) with any questions or comments.
